# dyscord

A simplistic implementation of the discord API.

## Main

[![Testing](https://github.com/isbe-house/dyscord/actions/workflows/python-testing.yml/badge.svg?branch=main)](https://github.com/isbe-house/dyscord/actions/workflows/python-testing.yml) [![Documentation Status](https://readthedocs.org/projects/dyscord/badge/?version=main)](https://dyscord.readthedocs.io/en/main/?badge=main)

[![Downloads](https://static.pepy.tech/personalized-badge/dyscord?period=month&units=international_system&left_color=grey&right_color=brightgreen&left_text=Downloads)](https://pepy.tech/project/dyscord)

## Dev

[![Testing](https://github.com/isbe-house/dyscord/actions/workflows/python-testing.yml/badge.svg?branch=dev)](https://github.com/isbe-house/dyscord/actions/workflows/python-testing.yml) [![Documentation Status](https://readthedocs.org/projects/dyscord/badge/?version=dev)](https://dyscord.readthedocs.io/en/dev/?badge=dev)


# Current Status

Very much an active WIP. The API to this library is not at all locked down. Users can expect aggressive changes to the API until we hit v1.0.0

# Documentation

Documentation can be found over at [Read The Docs](https://dyscord.readthedocs.io/).

We are following [Google Style](https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html) docstring patterns.

# Community

Come talk on the [Dyscord subreddit](https://www.reddit.com/r/dyscord/), or the [Dyscord discord](https://discord.gg/Q9NFzgZx)!

# Changelog

See the [Changelog](https://dyscord.readthedocs.io/en/main/changelog/).